@@ -23,6 +23,7 @@ import subprocess
 from robot import run, rebot
 from robot import __version__ as ROBOT_VERSION
 from robot.api import ExecutionResult
+from robot.errors import Information
 from robot.result.visitor import ResultVisitor
 from multiprocessing.pool import ThreadPool
 from robot.run import USAGE
@@ -39,6 +40,7 @@ def execute_and_wait_with(args):
         return
     time.sleep(0)
     datasources, outs_dir, options, suite_name, command, verbose = args
+    datasources = [d.encode('utf-8') if isinstance(d, unicode) else d for d in datasources]
     outs_dir = os.path.join(outs_dir, suite_name)
     cmd = command + _options_for_custom_executor(options, outs_dir, suite_name) + datasources
     cmd = [c if ' ' not in c else '"%s"' % c for c in cmd]
@@ -88,13 +90,18 @@ def _options_for_executor(options, outs_dir, suite_name):
 def _options_to_cli_arguments(opts):
     res = []
     for k, v in opts.items():
-        if isinstance(v, basestring):
+        if isinstance(v, str):
             res += ['--' + str(k), str(v)]
-        if isinstance(v, bool) and (v is True):
+        elif isinstance(v, unicode):
+            res += ['--' + str(k), v.encode('utf-8')]
+        elif isinstance(v, bool) and (v is True):
             res += ['--' + str(k)]
-        if isinstance(v, list):
+        elif isinstance(v, list):
             for value in v:
-                res += ['--' + str(k), str(value)]
+                if isinstance(value, unicode):
+                    res += ['--' + str(k), value.encode('utf-8')]
+                else:
+                    res += ['--' + str(k), str(value)]
     return res
 
 class GatherSuiteNames(ResultVisitor):
@@ -239,6 +246,20 @@ def main(args):
         _parallel_execute(datasources, options, outs_dir, pabot_args, suite_names)
         sys.exit(rebot(*sorted(glob(os.path.join(outs_dir, '**/*.xml'))),
                        **_options_for_rebot(options, datasources, start_time_string, _now())))
+    except Information, i:
+        print """A parallel executor for Robot Framework test cases.
+
+Supports all Robot Framework command line options and also following options (these must be before normal RF options):
+
+--verbose
+more output
+
+--command [ACTUAL COMMANDS TO START ROBOT EXECUTOR] --end-command
+RF script for situations where pybot is not used directly
+
+--processes [NUMBER OF PROCESSES]
+How many parallel executors to use (default max of 2 and cpu count)"""
+        print i.message
     finally:
         _print_elapsed(start_time, time.time())
 
